@@ -15,6 +15,7 @@
 # https://github.com/CalebBell/chemicals/blob/master/LICENSE.txt for details.
 import re
 import os
+import chemicals
 from chemicals.elements import (
     periodic_table, 
     homonuclear_elemental_gases,  
@@ -38,6 +39,10 @@ def spaceout_words(ID):
 def to_searchable_format(ID):    
     return spaceout_words(ID).replace('_', ' ')
 
+@forward(identifiers)
+def CAS_from_any(ID):
+    return pubchem_db.search(ID).CASs
+
 @forward(identifiers)
 class ChemicalMetadataDB:
     __slots__ = ('pubchem_index',
@@ -169,6 +174,17 @@ class ChemicalMetadataDB:
 
     def _search(self, ID):
         if not ID: raise ValueError('ID cannot be empty')
+        
+        if check_CAS(ID):
+            CAS_lookup = self.search_CAS(ID)
+            if CAS_lookup: return CAS_lookup
+            
+            # Handle the case of synonyms
+            CAS_alternate_loopup = self.search_name(ID)
+            if CAS_alternate_loopup: return CAS_alternate_loopup
+            
+            raise LookupError('a valid CAS number was recognized, but its not in the database')
+        
         ID = ID.replace('_', ' ')
         ID_lower = ID.lower()
         
@@ -205,16 +221,6 @@ class ChemicalMetadataDB:
             name_lookup = self.search_name(name)
             if name_lookup: return name_lookup
         
-        if check_CAS(ID):
-            CAS_lookup = self.search_CAS(ID)
-            if CAS_lookup: return CAS_lookup
-            
-            # Handle the case of synonyms
-            CAS_alternate_loopup = self.search_name(ID)
-            if CAS_alternate_loopup: return CAS_alternate_loopup
-            
-            raise LookupError('a valid CAS number was recognized, but its not in the database')
-        
         try: formula = serialize_formula(ID)
         except: pass
         else:
@@ -223,5 +229,6 @@ class ChemicalMetadataDB:
         
         raise LookupError(f'chemical {repr(ID)} not recognized')
 
-identifiers.pubchem_db = pubchem_db = ChemicalMetadataDB()
+chemicals.CAS_from_any = CAS_from_any
+chemicals.pubchem_db = identifiers.pubchem_db = pubchem_db = ChemicalMetadataDB()
 identifiers._pubchem_db_loaded = True
